@@ -434,6 +434,8 @@ typedef struct
     TimeType    end;		/* ending time of trace on screen */
     TimeType    marker;
     TimeType    prevmarker;	/* from last drawmarker()	        */
+    TimeType    resizemarker;   /* from last MaxSignalLength()          */
+    TimeType    resizemarker2;  /* from 2nd last MaxSignalLength()      */
     TimeType    lmbcache;	/* initial marker pos                   */
     TimeType    timecache;	/* to get around floating pt limitation */
     TimeType    laststart;      /* caches last set value                */
@@ -524,7 +526,9 @@ enum TraceEntFlagBits
   TR_BINGRAY_B, TR_GRAYBIN_B,
   TR_REAL2BITS_B, TR_TTRANSLATED_B,
   TR_POPCNT_B,
-  TR_FPDECSHIFT_B
+  TR_FPDECSHIFT_B,
+
+  TR_RSVD_B /* for use internally such as temporary caching of highlighting, not for use in traces */
 };
 
 #define TR_HIGHLIGHT 		(1<<TR_HIGHLIGHT_B)
@@ -572,6 +576,8 @@ enum TraceEntFlagBits
 
 #define TR_ANALOGMASK	(TR_ANALOG_STEP|TR_ANALOG_INTERPOLATED)
 
+#define TR_RSVD 		(1<<TR_RSVD_B)
+
 Trptr GiveNextTrace(Trptr t);
 Trptr GivePrevTrace(Trptr t);
 int UpdateTracesVisible(void);
@@ -591,6 +597,7 @@ void FreeCutBuffer(void);
 Trptr PasteBuffer(void);
 Trptr PrependBuffer(void);
 int TracesReorder(int mode);
+int DeleteBuffer(void);
 
 void import_trace(nptr np);
 
