@@ -116,6 +116,7 @@ GLOBALS->use_full_precision = g_old->use_full_precision;
 GLOBALS->show_base = g_old->show_base;
 GLOBALS->display_grid = g_old->display_grid;
 GLOBALS->highlight_wavewindow = g_old->highlight_wavewindow;
+GLOBALS->fill_waveform = g_old->fill_waveform;
 GLOBALS->use_standard_trace_select = g_old->use_standard_trace_select;
 GLOBALS->disable_mouseover = g_old->disable_mouseover;
 GLOBALS->keep_xz_colors = g_old->keep_xz_colors;
@@ -569,8 +570,10 @@ if(!GLOBALS)
 	GLOBALS->color_grid = old_g->color_grid;
 	GLOBALS->color_grid2 = old_g->color_grid2;
 	GLOBALS->color_high = old_g->color_high;
+	GLOBALS->color_highfill = old_g->color_highfill;
 	GLOBALS->color_low = old_g->color_low;
 	GLOBALS->color_1 = old_g->color_1;
+	GLOBALS->color_1fill = old_g->color_1fill;
 	GLOBALS->color_0 = old_g->color_0;
 	GLOBALS->color_mark = old_g->color_mark;
 	GLOBALS->color_mid = old_g->color_mid;
@@ -617,6 +620,7 @@ if(!GLOBALS)
 	GLOBALS->enable_fast_exit = old_g->enable_fast_exit;
 	GLOBALS->enable_ghost_marker = old_g->enable_ghost_marker;
 	GLOBALS->enable_horiz_grid = old_g->enable_horiz_grid;
+	GLOBALS->fill_waveform = old_g->fill_waveform;
 	GLOBALS->make_vcd_save_file = old_g->make_vcd_save_file;
 	GLOBALS->enable_vert_grid = old_g->enable_vert_grid;
 	GLOBALS->force_toolbars = old_g->force_toolbars;
@@ -632,6 +636,7 @@ if(!GLOBALS)
 	GLOBALS->show_base = old_g->show_base;
 	GLOBALS->display_grid = old_g->display_grid;
 	GLOBALS->highlight_wavewindow = old_g->highlight_wavewindow;
+	GLOBALS->fill_waveform = old_g->fill_waveform;
 	GLOBALS->use_standard_trace_select = old_g->use_standard_trace_select;
 	GLOBALS->use_big_fonts = old_g->use_big_fonts;
 	GLOBALS->use_full_precision = old_g->use_full_precision;
@@ -1842,6 +1847,10 @@ if(GLOBALS->use_toolbutton_interface)
 
 		if(!GLOBALS->disable_menus)
 			{
+#ifdef WAVE_USE_XID
+			if(GLOBALS->socket_xid) kill_main_menu_accelerators();
+#endif
+
 #ifdef WAVE_USE_MLIST_T
 			menubar = alt_menu_top(GLOBALS->mainwindow);
 #else
