@@ -37,6 +37,8 @@ int file_quit_cmd_callback (GtkWidget *widget, gpointer data);
 int set_wave_menu_accelerator(char *str);
 int execute_script(char *name, int dealloc_name);
 
+void kill_main_menu_accelerators(void); /* for conflicts with twinwave */
+
 struct stringchain_t
 {
 struct stringchain_t *next;
@@ -259,6 +261,7 @@ WV_MENU_MLKOFF,
 WV_MENU_VSG,
 WV_MENU_SEP9,
 WV_MENU_SHW,
+WV_MENU_FILL1,
 WV_MENU_SEP9B,
 WV_MENU_VSMO,
 WV_MENU_SEP9A,
@@ -428,4 +431,3 @@ void osx_menu_sensitivity(gboolean tr);
 #endif
 
 #endif
-
