@@ -38,6 +38,7 @@ int  f_autocoalesce_reversal (char *str);
 int  f_autoname_bundles (char *str);
 int  f_color_0 (char *str);
 int  f_color_1 (char *str);
+int  f_color_1fill (char *str);
 int  f_color_back (char *str);
 int  f_color_baseline (char *str);
 int  f_color_black (char *str);
@@ -51,6 +52,7 @@ int  f_color_dkgray (char *str);
 int  f_color_grid (char *str);
 int  f_color_grid2 (char *str);
 int  f_color_high (char *str);
+int  f_color_highfill (char *str);
 int  f_color_low (char *str);
 int  f_color_ltgray (char *str);
 int  f_color_mark (char *str);
@@ -83,6 +85,7 @@ int  f_enable_ghost_marker (char *str);
 int  f_enable_horiz_grid (char *str);
 int  f_enable_vcd_autosave (char *str);
 int  f_enable_vert_grid (char *str);
+int  f_fill_waveform (char *str);
 int  f_fontname_logfile (char *str);
 int  f_fontname_signals (char *str);
 int  f_fontname_waves (char *str);
