@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (c) Tony Bybell 1999.
  *
  * This program is free software; you can redistribute it and/or
@@ -33,23 +33,34 @@ if(GTK_TOGGLE_BUTTON(widget)->active)
 
 static void toggle1_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
 toggle_generic(widget, TR_RJUSTIFY);
 }
 static void toggle2_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
 toggle_generic(widget, TR_INVERT);
 }
 static void toggle3_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
 toggle_generic(widget, TR_REVERSE);
 }
 static void toggle4_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
 toggle_generic(widget, TR_EXCLUDE);
 }
 
 static void enter_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
   GLOBALS->flags_showchange_c_1=GLOBALS->flags_showchange_c_1&(~(TR_HIGHLIGHT|TR_NUMMASK));
 
   if(GTK_TOGGLE_BUTTON(GLOBALS->button1_showchange_c_1)->active)
@@ -94,6 +105,9 @@ static void enter_callback(GtkWidget *widget, GtkWidget *nothing)
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
   wave_gtk_grab_remove(GLOBALS->window_showchange_c_8);
   gtk_widget_destroy(GLOBALS->window_showchange_c_8);
   GLOBALS->window_showchange_c_8 = NULL;
@@ -119,7 +133,7 @@ void showchange(char *title, Trptr t, GtkSignalFunc func)
 
   /* fix problem where ungrab doesn't occur if button pressed + simultaneous accelerator key occurs */
   if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
-  
+
   GLOBALS->window_showchange_c_8 = gtk_window_new (GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
   install_focus_cb(GLOBALS->window_showchange_c_8, ((char *)&GLOBALS->window_showchange_c_8) - ((char *)GLOBALS));
 
@@ -262,6 +276,6 @@ void showchange(char *title, Trptr t, GtkSignalFunc func)
 
   gtk_container_add (GTK_CONTAINER (GLOBALS->window_showchange_c_8), main_vbox);
   gtk_widget_show (GLOBALS->window_showchange_c_8);
-  wave_gtk_grab_add(GLOBALS->window_showchange_c_8);  
+  wave_gtk_grab_add(GLOBALS->window_showchange_c_8);
 }
 
