@@ -302,8 +302,9 @@ GLOBALS->time_vlist_vcd_recoder_write value
 deltas from GLOBALS->time_vlist_vcd_recoder_write and on though stepping through list generated by vlist_emit_finalize()
 */
 
-struct vlist_packer_t *vlist_p;
-struct vlist_t * vlist_summary_index = ((struct vlist_t *)vlist_packer_create());
+struct vlist_packer_t *vlist_p = vlist_packer_create();
+struct vlist_t *vlist_summary_index;
+
 struct vcdsymbol *v = GLOBALS->vcdsymroot_vcd_recoder_c_3;
 guint64 val = (guint64)(unsigned long)GLOBALS->time_vlist_vcd_recoder_write;
 guint64 nval;
@@ -313,30 +314,29 @@ char *pnt;
 memset(buf, 0, sizeof(buf)); /* scan-build */
 
 #ifdef HAVE_SYS_STAT_H
-vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, (guint64)mystat->st_size);
-vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, (guint64)mystat->st_mtime);
+vlist_packer_emit_uv64(&vlist_p, (guint64)mystat->st_size);
+vlist_packer_emit_uv64(&vlist_p, (guint64)mystat->st_mtime);
 #else
-vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, (guint64)0);
-vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, (guint64)0);
+vlist_packer_emit_uv64(&vlist_p, (guint64)0);
+vlist_packer_emit_uv64(&vlist_p, (guint64)0);
 #endif
 
-vlist_packer_emit_uv32((struct vlist_packer_t **)(void *)&vlist_summary_index, finalize_cnt);
-vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, GLOBALS->time_vlist_count_vcd_recoder_c_1);
+vlist_packer_emit_uv32(&vlist_p, finalize_cnt);
+vlist_packer_emit_uv64(&vlist_p, GLOBALS->time_vlist_count_vcd_recoder_c_1);
 
-vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, val);
+vlist_packer_emit_uv64(&vlist_p, val);
 val = 0;
 while(v)
 	{
 	nptr n = v->narray[0];
 	nval = (guint64)(unsigned long)n->mv.mvlfac_vlist;
 
-	vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, nval - val);
+	vlist_packer_emit_uv64(&vlist_p, nval - val);
 	val = nval;
 
 	v = v->next;
 	}
 
-vlist_p = (struct vlist_packer_t *)vlist_summary_index;
 vlist_packer_finalize(vlist_p);
 vlist_summary_index = vlist_p->v;
 free_2(vlist_p);
